<?php
App::uses('AppController', 'Controller');
App::uses('CakeEmail', 'Network/Email');

class AdminController extends AppController {

	public $components = [
 		'Auth' => [
			'loginAction' => '/admin_signin/',
			'loginRedirect' => '/admin/profiles/',
			'logoutRedirect' => '/admin_signin/',
			'authenticate' => [
				'Form' => [
					'userModel' => 'User',
					'passwordHasher' => 'Blowfish'
				]
			],
			'authError' => 'You are currently not logged in.',
			'sessionKey' => 'Auth.Admin',
		]
	];	
	
	public function beforeFilter()
	{
		parent::beforeFilter();
		$this->layout = 'admin';
		AuthComponent::$sessionKey = 'Auth.Admin'; 
		$this->Auth->allow('signin', 'signup');
		$this->set('user', $this->Auth->user());

		$this->paginate = ['limit'=> 50];
		$this->search = isset($this->request->query['search'])?trim($this->request->query['search']):'';
		$this->set('search', $this->search); 
		$this->search = addslashes(urldecode($this->search));
		$this->search = preg_replace( '/  +/', ' ', $this->search );
		$this->search = '%'.str_replace(' ', '%', $this->search).'%'; 
		if(!empty($this->request->data['User']['token']))
			$this->User->token = $this->request->data['User']['token'];
	}

	public function dashboard()
	{
	}

	public function upgrades()
	{
		if(!empty($this->params->named['approve'])) {
			$data = $this->Upgrade->read(['id','profile_id','access','approved','status','domain','domain_ownership'], $this->params->named['approve']);
			$this->Upgrade->set('status', 'approved');
			$this->Upgrade->set('approved', date('Y-m-d H:i:s'));
			$this->Upgrade->save();
			if(!empty($data['Upgrade'])) {
				$this->Profile->read(['id','access','domain','domain_ownership','last_upgrade_date'], $data['Upgrade']['profile_id']);
				$this->Profile->set('access', $data['Upgrade']['access']);
				$this->Profile->set('domain', $data['Upgrade']['domain']);
				$this->Profile->set('domain_ownership', $data['Upgrade']['domain_ownership']);
				$this->Profile->set('last_upgrade_date', date('Y-m-d H:i:s'));
				$this->Profile->save();
			}
			$this->redirect($this->referer());
		}

		$this->paginate += [
			'conditions' => ['Upgrade.status' => 'new'],
			'order' => ['Upgrade.created'=>'desc']
		];
		$this->request->data = $this->Paginate('Upgrade');

		$options = [
			'conditions' => ['Upgrade.status !=' => 'new'],
			'order' => ['Upgrade.modified'=>'desc',]
		];
		$this->set('recentUpgrades', $this->Upgrade->find('all', $options));
	}

	public function profiles()
	{
		if(!empty($this->params->named['unpublish'])) {
			$this->Profile->read(['id','published'], $this->params->named['unpublish']);
			$this->Profile->set('published', 0);
			$this->Profile->save();
			$this->redirect($this->referer());
		} elseif(!empty($this->params->named['publish'])) {
			$this->Profile->read(['id','published'], $this->params->named['publish']);
			$this->Profile->set('published', 1);
			$this->Profile->save();
			$this->redirect($this->referer());
		}
		$this->request->data = $this->Paginate('Profile');
	}

		public function profiles_add()
		{
			$this->render('profiles_edit');
		}

		public function profiles_edit($id = null)
		{
			if ($this->request->is('post') || $this->request->is('put')) {
				if ($this->Profile->save($this->request->data)) {
					$this->Session->setFlash("Profile has been saved.");
					if(!empty($this->request->data['saveReturn']))
						return $this->redirect($this->request->data['saveReturn']);
					else
						$this->redirect('/admin/profiles_edit/'.$this->Profile->id);
				} else {
					$this->Session->setFlash('Error saving record');
				}
			} else {
				$this->request->data = $this->Profile->read(null, $id);
			}
		}

		public function profiles_cp($id = null)
		{
			if ($this->request->is('post') || $this->request->is('put')) {

				if(!empty($this->request->data['Profile']['password_new']) 
					&& !empty($this->request->data['Profile']['password_confirmation'])
					&& $this->request->data['Profile']['password_new'] == $this->request->data['Profile']['password_confirmation'] 
					&& $this->request->data['Profile']['token'] == md5(date('y-m-d').date('d-m-y')))
					$this->request->data['Profile']['password'] = $this->request->data['Profile']['password_new'];

				if ($this->Profile->save($this->request->data)) {
					$this->Session->setFlash("Password has been changed.");
					$this->redirect('/admin/profiles_edit/'.$this->Profile->id);
				} else {
					$this->Session->setFlash('Error saving form');
				}

			} else {
				$this->request->data = $this->Profile->read(null, $id);
			}
		}

	// public function typesSort()
	// {
	// 	$types = $this->Type->find('all');
	// 	foreach($types as $i=>$row) {
	// 		$types[$i]['Type']['name'] = ucwords($types[$i]['Type']['name']);
	// 		// $types[$i]['Type']['slug'] = trim($types[$i]['Type']['slug']);
	// 	}
	// 	debug($this->Type->saveAll($types));
	// 	exit;
	// }

	public function types()
	{
		if(!empty($this->params->named['unpublish'])) {
			$this->Type->read(['id','published'], $this->params->named['unpublish']);
			$this->Type->set('published', 0);
			$this->Type->save();
			$this->redirect($this->referer());
		} elseif(!empty($this->params->named['publish'])) {
			$this->Type->read(['id','published'], $this->params->named['publish']);
			$this->Type->set('published', 1);
			$this->Type->save();
			$this->redirect($this->referer());
		}
		$this->request->data = $this->Paginate('Type');
	}

		public function types_add()
		{
			$this->render('types_edit');
			$this->set('industries', $this->Industry->find('list'));
		}

		public function types_edit($id = null)
		{
			if ($this->request->is('post') || $this->request->is('put')) {
				if ($this->Type->save($this->request->data)) {
					$this->Session->setFlash("Record has been saved.");
					if(!empty($this->request->data['saveReturn']))
						return $this->redirect($this->request->data['saveReturn']);
					else
						$this->redirect('/admin/types_edit/'.$this->Type->id);
				} else {
					$this->Session->setFlash('Error saving record');
				}
			} else {
				$this->request->data = $this->Type->read(null, $id);
			}
			$this->set('industries', $this->Industry->find('list'));
		}

		public function types_del($id) {
			if($this->Type->delete($id)) {
				$this->Session->setFlash("Record has been deleted");
				$this->redirect($this->referer());
			}
		}



	public function industries()
	{
		$this->request->data = $this->Paginate('Industry');
	}

		public function industries_add()
		{
			$this->render('industries_edit');
		}

		public function industries_edit($id = null)
		{
			if ($this->request->is('post') || $this->request->is('put')) {
				if(empty($this->request->data['Industry']['slug']))
					$this->request->data['Industry']['slug'] = $this->toSef($this->request->data['Industry']['name']);
				if ($this->Industry->save($this->request->data)) {
					$this->Session->setFlash("Record has been saved.");

					$data = $this->Industry->read(['id','image'], $this->Industry->id);
					$update = false;
					if(!empty($this->request->data['Industry']['image_remove']) && !empty($data['Industry']['image'])){
						$this->deleteFile($data['Industry']['image']);
						$data['Industry']['image'] = '';
						$update = true;
					}
					$path = '/img/covers/'.$this->Auth->user('username').'-industries-'.$this->Industry->id.'.jpg';
					if(!empty($this->request->data['Industry']['image_input']) && 
						$this->Files->uploadImage($this->request->data['Industry']['image_input'], ['type'=>'cover', 'filename' => $path])) {
						$data['Industry']['image'] = $path;
						$update = true;
					}
					if($update)
						$this->Industry->save($data);

					if(!empty($this->request->data['saveReturn']))
						return $this->redirect($this->request->data['saveReturn']);
					else
						$this->redirect('/admin/industries_edit/'.$this->Industry->id);
				} else {
					$this->Session->setFlash('Error saving record');
				}
			} else {
				$this->request->data = $this->Industry->read(null, $id);
			}
		}

		public function industries_del($id) {
			if($this->Industry->delete($id)) {
				$this->Session->setFlash("Record has been deleted");
				$this->redirect($this->referer());
			}
		}


	// public function signup()
	// {
	// 	$this->layout = 'blank';
	// 	if ($this->request->is('post')) {
	// 		$this->User->create();

	// 		if ($this->User->save($this->request->data)) {
	// 			$data = $this->User->findById($this->User->id);
	// 			unset($data['User']['password']);
	// 			$this->request->data = $data['User'];
	// 			$this->Auth->login($this->request->data);
	// 			return $this->redirect('/admin/');
	// 		}
	// 		$this->Session->setFlash(
	// 			__('The user could not be saved. Please, try again.')
	// 		);
	// 	}
	// }

	public function signin()
	{
		$this->layout = 'blank';
		if ($this->request->is('post')) {
			if ($this->Auth->login()) {
				return $this->redirect($this->Auth->redirectUrl());
			}
			$this->Session->setFlash(__('Invalid username or password, try again'));
		}
	}

	public function change_password()
	{
		if ($this->request->is('post') || $this->request->is('put')) {
			$this->request->data['User']['id'] = $this->Auth->user('id');
			if(!empty($this->request->data['User']['password_new']) 
				&& !empty($this->request->data['User']['password_confirmation'])
				&& $this->request->data['User']['password_new'] == $this->request->data['User']['password_confirmation'] 
				&& $this->request->data['User']['token'] == md5(date('y-m-d').date('d-m-y')))
				$this->request->data['User']['password'] = $this->request->data['User']['password_new'];
			if ($this->User->save($this->request->data)) {
				$this->Session->setFlash("Password has been changed.");
				$this->redirect('/admin/');
			} else {
				$this->Session->setFlash('Error saving form');
			}
		}
		$this->request->data = $this->User->findById($this->Auth->user('id'));
	}


	public function signout() {
		return $this->redirect($this->Auth->logout());
	}

}