<?php
App::uses('AppController', 'Controller');

class ProfilesController extends AppController {

	public $profile = [];

	public function beforeRender() {
		parent::beforeRender();
		
		if(!empty($this->profile['title']) && !empty(Globals::$title))
			Globals::$title .= ' - '. $this->profile['title'];
		elseif(empty(Globals::$title))
			Globals::$title = $this->profile['title'];

		if(!$this->profile['limit']['noads'])
			Globals::$title .= ' | Pinoys on Web';
	}

	public function beforeFilter()
	{
		parent::beforeFilter();

		$base = Router::url('/', true);
		$this->layout = 'profiles';
		$this->profile = $this->getProfile();

		if(empty($this->profile)) {
			return $this->redirect($base.'404/', 404);
		}

		$this->profile['limit'] = $this->Profile->accessLimits[$this->profile['access']];
		$this->profile['title'] = !empty($this->profile['business_name'])? $this->profile['business_name'] : ucwords($this->profile['username']);
		$request_uri = str_replace('/'.$this->profile['username'].'/','/',$this->params->here);

		// redirect between domain and username path
		if(IS_POWHOST) {
			if($this->profile['path'] == 'domain' && $this->profile['limit']['path'] == 'domain' && !empty($this->profile['domain'])) {
				$redirectUrl = str_replace($this->profile['username'], $this->profile['domain'], $this->params->here);
				$redirectUrl = ($this->profile['domain_ssl'] ? 'https:/' : 'http:/') .$redirectUrl;
				$this->redirect($redirectUrl, 301);
			}
		} else {
			if($this->profile['path'] != 'domain' || $this->profile['limit']['path'] != 'domain' || empty($this->profile['domain'])) {
				$redirectUrl = POWHOST.'/'.$this->profile['username'].$this->params->here;
				$this->redirect($redirectUrl, 301);
			}
		}

		if(strstr($base,'pow.ph') && !empty($this->profile['username']))
			$base .= $this->profile['username'].'/';
		define('BASE', $base);

		$this->set('listing_count', $this->Listing->find('count',['conditions'=>[
			'profile_id' => $this->profile['id'],
			'availability !=' => 'hide'
		]]));
		$this->set('pages', $this->Page->find('list', [
			'fields' => ['slug','title'],
			'conditions'=>['profile_id' => $this->profile['id'], 'published'=>1, 'menu'=>1],
			'order' => ['order'],
			'limit' => !empty($this->profile['limit']['pages']) ? $this->profile['limit']['pages'] : null
		]));

		$this->set('profile', $this->profile);
		$this->set('request_uri', $request_uri);

		if(!empty($this->profile['id']))
			$this->Visit->track($this->profile['id'],$this->profile['login_ip'],$request_uri);
	}

	private function getProfile()
	{
		$domain = in_array(env('HTTP_HOST'), ['pow.test', 'pow.ph']) ? false : env('HTTP_HOST');

		if(!$domain && !empty($this->request->params['username'])) {

			$tmp = $this->Profile->find('first', ['conditions'=>[
				'username' => strtolower($this->request->params['username'])
			]]);
			return !empty($tmp['Profile']) ? $tmp['Profile'] : [];

		} elseif($domain) {
			$tmp = $this->Profile->find('first', ['conditions'=>[
				//'access' => ['plus','pro'],
				'domain' => $domain
			]]);

			if(isset($tmp['Profile']['password']))
				unset($tmp['Profile']['password']);
			return !empty($tmp['Profile']) ? $tmp['Profile'] : [];
		} else
			return [];
	}


	public function index()
	{
		$options = [
			'conditions'=>[
				'profile_id' => $this->profile['id'],
				'availability !=' => 'hide'
			],
			'limit' => 3,
			'order' => ['created' => 'desc']
		];
		
		if($this->profile['listing_home_sort'] == 'none')
			$listings = [];
		elseif($this->profile['listing_home_sort'] == 'featured') {
			$options['conditions']['featured'] = 1;
			$options['order'] = ['featured' => 'desc', 'created' => 'desc'];
			$listings = $this->Listing->find('all', $options);
		} else {
			$listings = $this->Listing->find('all', $options);
		}
	
		$this->set('listings', $listings);
	}

	public function page()
	{
		if($this->params->page == '404') {
			Globals::$robots = 'noindex,nofollow';
			Globals::$title = '404';
			$this->render('404');	
		} elseif($this->data = $this->Page->find('first', [
			'conditions'=>[
				'profile_id' => $this->profile['id'],
				'slug'=>$this->params->page,
				'published'=>1
			]])) {
			if(!empty($this->data['Page']['title']))
				Globals::$title = $this->data['Page']['title'];
		} else {
			$this->redirect(BASE.'404/', 404);
		}
	}

	public function listing()
	{
		$options = [
			'conditions'=>[
				'profile_id' => $this->profile['id'],
				'availability !=' => 'hide'
			],
			'order' => ['created' => 'desc'],
			'limit' => !empty($this->profile['limit']['listing']) ? $this->profile['limit']['listing'] : null
		];
		if($this->profile['listing_page_sort'] == 'featured') {
			$options['order'] = ['featured' => 'desc', 'created' => 'desc'];
			$this->data = $this->Listing->find('all', $options);
		} else {
			$this->data = $this->Listing->find('all', $options);
		}

		$title = !empty($this->profile['listing_page_title']) ? $this->profile['listing_page_title'] : 'Listing';
		Globals::$title = $title;
		Globals::$robots = 'noindex,nofollow';
	}

	public function listing_view()
	{
		$this->data = $this->Listing->find('first', [
			'conditions'=>[
				'id' => $this->params->id,
				'profile_id' => $this->profile['id'],
				'availability !=' => 'hide'
			]
		]);
		if(!empty($this->data['Listing']['name']))
			Globals::$title = $this->data['Listing']['name'];
	}

}