<?php
App::uses('AppController', 'Controller');
App::uses('CakeEmail', 'Network/Email');

class SettingsController extends AppController {

	public $components = [
 		'Auth' => [
			'loginAction' => '/signin/',
			'loginRedirect' => '/settings/dashboard/',
			'logoutRedirect' => '/signin/',
			'authenticate' => [
				'Form' => [
					'userModel' => 'Profile',
					'passwordHasher' => 'Blowfish'
				]
			],
			'authError' => 'You are currently not logged in.',
			'sessionKey' => 'Auth.Settings',
		]
	];
	public $profile = [];
	
	public function beforeFilter()
	{
		parent::beforeFilter();
		$this->layout = 'settings';
		AuthComponent::$sessionKey = 'Auth.Settings'; 
		$this->Auth->authenticate[AuthComponent::ALL] = array('userModel' => 'Profile');
		$this->Auth->allow('signin', 'forgot', 'reset', 'signup', 'signup_next', 'signup_finished');
		$this->profile = $this->profile();
		if($this->profile) {
			$this->profile['limit'] = $this->Profile->accessLimits[$this->profile['access']];
			$this->set('profile', $this->profile);
		}
		if(!empty($this->request->data['Profile']['token']))
			$this->Profile->token = $this->request->data['Profile']['token'];
	}


	public function dashboard()
	{
		$options = [
			'fields' => 'Upgrade.*',
			'conditions' => ['profile_id' => $this->Auth->user('id'), 'status'=>'new'],
			'order' => ['created'=>'desc','approved'=>'desc']
		];
		$this->set('upgrade', $this->Upgrade->find('all', $options));

		$this->Visit->virtualFields['page_count'] = 'COUNT(Visit.page)';
		$options = [
			'fields' => 'Visit.page, Visit.page_count, Visit.ip, Visit.created',
			'conditions' => ['profile_id' => $this->Auth->user('id')],
			'group'=> 'Visit.page',
			'order' => ['page_count'=>'desc','Visit.page'=>'desc']
		];
		$this->set('visits', $this->Visit->find('all', $options));
	}

	public function account()
	{
		if ($this->request->is('post') || $this->request->is('put')) {
			$this->request->data['Profile']['username'] = strtolower($this->request->data['Profile']['username']);
			$this->request->data['Profile']['id'] = $this->Auth->user('id');
			if ($this->Profile->save($this->request->data)) {
				$this->Session->setFlash("Account Information has been updated.");
				$this->redirect('/settings/account/');
			} else {
				$this->Session->setFlash('Error saving form');
			}
		}
		$this->request->data = $this->Profile->findById($this->Auth->user('id'));
		$types = [];
		foreach ($this->Type->find('list', ['fields'=>['slug','name'],'conditions'=>['published'=>1]]) as $key=>$row)
			$types[] = ['id'=>$key, 'value'=>$key];
		$this->set('types', $types);
	}

	public function change_password()
	{
		if ($this->request->is('post') || $this->request->is('put')) {
			$this->request->data['Profile']['id'] = $this->Auth->user('id');
			if(!empty($this->request->data['Profile']['password_new']) 
				&& !empty($this->request->data['Profile']['password_confirmation'])
				&& $this->request->data['Profile']['password_new'] == $this->request->data['Profile']['password_confirmation'] 
				&& $this->request->data['Profile']['token'] == md5(date('y-m-d').date('d-m-y')))
				$this->request->data['Profile']['password'] = $this->request->data['Profile']['password_new'];
			if ($this->Profile->save($this->request->data)) {
				$this->Session->setFlash("Password has been changed.");
				$this->redirect('/settings/account/');
			} else {
				$this->Session->setFlash('Error saving form');
			}
		}
		$this->request->data = $this->Profile->findById($this->Auth->user('id'));
	}

	public function homepage()
	{
		if ($this->request->is('post') || $this->request->is('put')) {
			$this->request->data['Profile']['id'] = $this->Auth->user('id');
			if ($this->Profile->save($this->request->data)) {
				$this->Session->setFlash("Template Styling has been updated.");
				$tmp = $this->Profile->read(['id','header_logo','banner_image','business_image'], $this->Auth->user('id'));
				
				$update = false;
				if(!empty($this->request->data['Profile']['header_logo_remove']) && !empty($tmp['Profile']['header_logo'])){
					$this->deleteFile($tmp['Profile']['header_logo']);
					$this->request->data['Profile']['header_logo'] = '';
					$update = true;
				}
				if(!empty($this->request->data['Profile']['banner_image_remove']) && !empty($tmp['Profile']['banner_image'])){
					$this->deleteFile($tmp['Profile']['banner_image']);
					$this->request->data['Profile']['banner_image'] = '';
					$update = true;
				}
				if(!empty($this->request->data['Profile']['business_image_remove']) && !empty($tmp['Profile']['business_image'])){
					$this->deleteFile($tmp['Profile']['business_image']);
					$this->request->data['Profile']['business_image'] = '';
					$update = true;
				}

				$path = '/up/profile/'.$this->Auth->user('username').'-header-logo.jpg';
				if(!empty($this->request->data['Profile']['header_logo_input']) && 
					$this->Files->uploadImage($this->request->data['Profile']['header_logo_input'], ['type'=>'logo', 'filename' => $path])) {
					$this->request->data['Profile']['header_logo'] = $path;
					$update = true;
				}
				$path = '/up/profile/'.$this->Auth->user('username').'-banner-image.jpg';
				if(!empty($this->request->data['Profile']['banner_image_input']) && 
					$this->Files->uploadImage($this->request->data['Profile']['banner_image_input'], ['type'=>'cover', 'filename' => $path])) {
					$this->request->data['Profile']['banner_image'] = $path;
					$update = true;
				}
				$path = '/up/profile/'.$this->Auth->user('username').'-business-image.jpg';
				if(!empty($this->request->data['Profile']['business_image_input']) && 
					$this->Files->uploadImage($this->request->data['Profile']['business_image_input'], ['type'=>'image', 'filename' => $path])) {
					$this->request->data['Profile']['business_image'] = $path;
					$update = true;
				}

				if($update)
					$this->Profile->save($this->request->data);

				$this->redirect('/settings/homepage/');
			} else {
				$this->Session->setFlash('Error saving form');
			}
		}
		$this->request->data = $this->Profile->findById($this->Auth->user('id'));
	}

	public function pages()
	{	
		if(!empty($this->params->named['menuoff'])) {
			$this->Page->toggle($this->params->named['menuoff'], 'menu', $this->Auth->user('id'));
			$this->redirect($this->referer());
		} elseif(!empty($this->params->named['menuon'])) {
			$this->Page->toggle($this->params->named['menuon'], 'menu', $this->Auth->user('id'));
			$this->redirect($this->referer());
		} elseif(!empty($this->params->named['moveup'])) {
			$this->Page->move('up', $this->params->named['moveup'], $this->Auth->user('id'));
			$this->redirect($this->referer());
		} elseif(!empty($this->params->named['movedown'])) {
			$this->Page->move('down', $this->params->named['movedown'], $this->Auth->user('id'));
			$this->redirect($this->referer());
		}

		$this->request->data = $this->Page->find('all', [
			'conditions'=>['profile_id' => $this->Auth->user('id'),],
			'order' => 'order asc',
			'limit' => !empty($this->profile['limit']['pages']) ? $this->profile['limit']['pages'] : null
		]);
	}

		public function pages_add()
		{
			$this->render('pages_edit');
		}

		public function pages_edit($id=null)
		{		
			if ($this->request->is('post') || $this->request->is('put')) {

				if(!$this->Page->isAuth($this->request->data['Page']['id'], $this->Auth->user('id')))
					$this->redirect('/settings/pages/');

				if(empty($this->request->data['Page']['id'])) {
					$tmp = $this->Page->find('first', [
						'field' => ['order'], 
						'conditions' => [ 'profile_id'=>$this->Auth->user('id'), 'order >' => 0],
						'order' => 'order desc'
					]);
					$this->request->data['Page']['order'] = !empty($tmp['Page']['order']) ? $tmp['Page']['order'] + 1 : 1;
				}
				
				$this->request->data['Page']['profile_id'] = $this->Auth->user('id');
				if ($this->Page->save($this->request->data)) {
					$this->Session->setFlash("Page has been updated.");

					$data = $this->Page->read(['id','image'], $this->Page->id);
					
					$update = false;
					if(!empty($this->request->data['Page']['image_remove']) && !empty($data['Page']['image'])){
						$this->deleteFile($data['Page']['image']);
						$data['Page']['image'] = '';
						$update = true;
					}

					$path = '/up/pages/'.$this->Auth->user('username').'-page-'.$this->Page->id.'.jpg';
					if(!empty($this->request->data['Page']['image_input']) && 
						$this->Files->uploadImage($this->request->data['Page']['image_input'], ['type'=>'page-image', 'filename' => $path])) {
						$data['Page']['image'] = $path;
						$update = true;
					}

					if($update)
						$this->Page->save($data);

					if(!empty($this->request->data['saveReturn']))
						return $this->redirect($this->request->data['saveReturn']);
					else
						$this->redirect('/settings/pages_edit/'.$this->Page->id);
				} else {
					$this->Session->setFlash('Error saving form');
				}
			}
			$this->request->data = $this->Page->find('first', [
				'conditions'=>[
					'id' => $id, 
					'profile_id' => $this->Auth->user('id'),
				]
			]);
		}
		public function pages_del($id) {
			$data = $this->Page->read(['id','image'],$id);
			$image = !empty($data['Page']['image']) ? $data['Page']['image'] : '';
			if($this->Page->isAuth($id, $this->Auth->user('id')) && $this->Page->delete($id)) {
				$this->deleteFile($image);
				$this->Session->setFlash("Page has been deleted");
			}
			$this->redirect('/settings/pages/');
		}

	public function listings()
	{
		if(!empty($this->params->named['unfeatured'])) {
			$this->Listing->toggle($this->params->named['unfeatured'], 'featured', $this->Auth->user('id'));
			$this->redirect($this->referer());
		} elseif(!empty($this->params->named['featured'])) {
			$this->Listing->toggle($this->params->named['featured'], 'featured', $this->Auth->user('id'));
			$this->redirect($this->referer());
		}

		if ($this->request->is('post') || $this->request->is('put')) {
			$this->request->data['Profile']['id'] = $this->Auth->user('id');
			if ($this->Profile->save($this->request->data)) {
				$this->Session->setFlash("Listing page has been updated.");
				$this->redirect('/settings/listings/');
			} else {
				$this->Session->setFlash('Error saving form');
			}
		}
		$this->request->data = $this->Profile->findById($this->Auth->user('id'));

		$listing = $this->Listing->find('all', [
			'conditions'=>[ 'profile_id' => $this->Auth->user('id'), ],
			'limit' => !empty($this->profile['limit']['listing']) ? $this->profile['limit']['listing'] : null
		]);
		$this->set('listing',$listing);
	}

		public function listings_add()
		{
			$this->render('listings_edit');
		}

		public function listings_edit($id=null)
		{		
			if ($this->request->is('post') || $this->request->is('put')) {

				if(!$this->Listing->isAuth($this->request->data['Listing']['id'], $this->Auth->user('id')))
					$this->redirect('/settings/listings/');

				$this->request->data['Listing']['profile_id'] = $this->Auth->user('id');
				if ($this->Listing->save($this->request->data)) {
					$this->Session->setFlash("Listing has been updated.");

					$data = $this->Listing->read(['id','image'], $this->Listing->id);
					$update = false;
					if(!empty($this->request->data['Listing']['image_remove']) && !empty($data['Listing']['image'])){
						$this->deleteFile($data['Listing']['image']);
						$data['Listing']['image'] = '';
						$update = true;
					}
					$path = '/up/listings/'.$this->Auth->user('username').'-listing-'.$this->Listing->id.'.jpg';
					if(!empty($this->request->data['Listing']['image_input']) && 
						$this->Files->uploadImage($this->request->data['Listing']['image_input'], ['type'=>'listing', 'filename' => $path])) {
						$data['Listing']['image'] = $path;
						$update = true;
					}
					if($update)
						$this->Listing->save($data);

					if(!empty($this->request->data['saveReturn']))
						return $this->redirect($this->request->data['saveReturn']);
					else
						$this->redirect('/settings/listings_edit/'.$this->Listing->id);
				} else {
					$this->Session->setFlash('Error saving form');
				}
			}
			$this->request->data = $this->Listing->find('first', [
				'conditions'=>[
					'id' => $id, 
					'profile_id' => $this->Auth->user('id'),
				]
			]);
		}
		public function listings_del($id) {
			$data = $this->Listing->read(['id','image'],$id);
			$image = !empty($data['Listing']['image']) ? $data['Listing']['image'] : '';
			if($this->Listing->isAuth($id, $this->Auth->user('id')) && $this->Listing->delete($id)) {
				if($image && file_exists(WWW_ROOT.$image))
					@unlink(WWW_ROOT.$image);
				$this->Session->setFlash("Listing has been deleted");
			}
			$this->redirect('/settings/listings/');
		}


	public function upgrade()
	{
		if(!empty($this->params->named['cancel'])) {
			$tmp = $this->Upgrade->read(['id','profile_id','status'], $this->params->named['cancel']);
			if($tmp['Upgrade']['profile_id'] == $this->Auth->user('id')) {
				$this->Upgrade->set('status', 'cancelled');
				$this->Upgrade->save();
			}
			$this->redirect($this->referer());
		}

		$options = [
			'fields' => 'Upgrade.*',
			'conditions' => ['profile_id' => $this->Auth->user('id')],
			'order' => ['created'=>'desc','approved'=>'desc']
		];
		$this->set('recentUpgrades', $this->Upgrade->find('all', $options));

		$this->set('profile', $this->profile);
		$this->set('upgradeOptions', $this->upgradeOptions($this->profile['access']));
	}

		public function upgrade_add()
		{
			$selectedUpgrade = !empty($this->params->pass[0]) ? $this->params->pass[0] : false;
			$this->request->data['Upgrade']['access'] = $selectedUpgrade;
			$this->request->data['Upgrade']['domain'] = !empty($this->profile['domain']) ? $this->profile['domain'] : '';
			$this->request->data['Upgrade']['domain_ownership'] = !empty($this->profile['domain_ownership']) ? $this->profile['domain_ownership'] : 'free';
			$this->set('profile', $this->profile);
			$this->set('upgradeOptions', $this->upgradeOptions($this->profile['access']));
			$this->set('selectedUpgrade', $selectedUpgrade);
			$this->render('upgrade_edit');
		}

		public function upgrade_edit($id=null)
		{		
			if ($this->request->is('post') || $this->request->is('put')) {

				if(!$this->Upgrade->isAuth($this->request->data['Upgrade']['id'], $this->Auth->user('id')))
					$this->redirect('/settings/upgrades/');

				$this->request->data['Upgrade']['profile_id'] = $this->Auth->user('id');
				if ($this->Upgrade->save($this->request->data)) {
					$this->Session->setFlash("Upgrade request has been submitted.");

					$data = $this->Upgrade->read(['id','image'], $this->Upgrade->id);
					$update = false;

					$path = '/up/upgrades/'.$this->Auth->user('username').'-upgrades-'.$this->Upgrade->id.'.jpg';
					if(!empty($this->request->data['Upgrade']['image_input']) && 
						$this->Files->uploadImage($this->request->data['Upgrade']['image_input'], ['type'=>'listing', 'filename' => $path])) {
						$data['Upgrade']['image'] = $path;
						$update = true;
					}

					if($update)
						$this->Upgrade->save($data);

					$this->redirect('/settings/upgrade/');
				} else {
					$this->Session->setFlash('Error saving form');
				}
			}
			$this->request->data = $this->Upgrade->find('first', [
				'conditions'=>[
					'id' => $id, 
					'profile_id' => $this->Auth->user('id'),
				]
			]);
	
			$this->set('upgradeOptions', $this->upgradeOptions($this->profile['access']));
		}

	// public function signup()
	// {
	// 	$this->layout = 'blank';
	// 	if ($this->request->is('post') || $this->request->is('put')) {
	// 		$this->Profile->create();
	// 		if(!empty($this->request->data['Profile']['password_new']) 
	// 			&& !empty($this->request->data['Profile']['password_confirmation'])
	// 			&& $this->request->data['Profile']['password_new'] == $this->request->data['Profile']['password_confirmation']) {
	// 			$this->request->data['Profile']['password'] = $this->request->data['Profile']['password_new'];
	// 		}
	// 		$this->request->data['Profile']['username'] = strtolower($this->request->data['Profile']['username']);
	// 		$this->request->data['Profile']['banner_image'] = '/img/covers/admin-industries-'.rand(1,13).'.jpg';
	// 		if ($this->Profile->save($this->request->data)) {
	// 			$data = $this->Profile->findById($this->Profile->id);

	// 			$Email = new CakeEmail();
	// 			$Email->template('signup')
	// 				->viewVars(['profile' => $data['Profile']])
	// 				->subject('Welcome to Pinoys on Web!')
	// 				->to($data['Profile']['email'])
	// 				->send();

	// 			unset($data['Profile']['password']);
	// 			$this->request->data = $data['Profile'];
	// 			$this->Auth->login($this->request->data);
	// 			return $this->redirect('/signup-next/');
	// 		}
	// 		$this->Session->setFlash(__('Account could not be created. Please, try again.'));
	// 	}
	// 	Globals::$title = 'Sign up - Pinoys on Web';
	// }
	// 	public function signup_next()
	// 	{
	// 		$this->layout = 'blank';
	// 		if(!$this->Auth->user('id'))
	// 			return $this->redirect('/signin/');

	// 		if ($this->request->is('post') || $this->request->is('put')) {
	// 			if(!empty($this->request->data['Profile']['types'])) {
	// 				$types = explode(",",$this->request->data['Profile']['types']);
	// 				if(!empty($types[0])) {
	// 					$type = $this->Type->findBySlug($types[0]);
	// 					if(!empty($type['Industry']['image'])){
	// 						$this->request->data['Profile']['banner_image'] = $type['Industry']['image'];
	// 					}
	// 				}
	// 			}
	// 			if(empty($this->request->data['Profile']['banner_image']))
	// 				$this->request->data['Profile']['banner_image'] = '/img/covers/admin-industries-'.rand(1,13).'.jpg';

	// 			$this->request->data['Profile']['business_summary'] = '<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in reprehenderit in voluptate velit esse cillum dolore eu fugiat nulla pariatur.</p>';
	// 			$this->request->data['Profile']['id'] = $this->Auth->user('id');
	// 			$this->request->data['Profile']['signup_finished'] = 1;
	// 			if ($this->Profile->save($this->request->data)) {
	// 				return $this->redirect('/signup-finished/');
	// 			} else {
	// 				$this->Session->setFlash('Error saving form');
	// 			}
	// 		}
	// 		$types = $this->Type->find('list', ['fields'=>['slug','name'],'conditions'=>['published'=>1]]);
	// 		array_unshift($types,[''=>'business type']);
	// 		$this->set('types', $types);
	// 		Globals::$title = 'Sign up Next Step - Pinoys on Web';
	// 	}
	// 	public function signup_finished()
	// 	{
	// 		$this->layout = 'blank';
	// 		Globals::$title = 'Sign up Finished - Pinoys on Web';
	// 		$this->set('username', $this->Auth->user('username'));
	// 	}

	public function reset()
	{
		$this->layout = 'blank';
		Globals::$title = 'Reset password - Pinoys on Web';
		$status = 'invalid';
		$data = $this->Profile->findByPasswordToken($this->request->id);

		if ($this->request->is('post') || $this->request->is('put')) {

			$status = 'failed';
			if(!empty($data['Profile']['password_timeout']) && $data['Profile']['password_timeout'] >= time() ){
				$this->request->data['Profile']['id'] = $data['Profile']['id'];
				$this->request->data['Profile']['username'] = $data['Profile']['username'];
				$this->request->data['Profile']['email'] = $data['Profile']['email'];
				if(!empty($this->request->data['Profile']['password_new']) 
					&& !empty($this->request->data['Profile']['password_confirmation'])
					&& $this->request->data['Profile']['password_new'] == $this->request->data['Profile']['password_confirmation']) {
						$this->request->data['Profile']['password'] = $this->request->data['Profile']['password_new'];
						$this->request->data['Profile']['password_timeout'] = '';
						$this->request->data['Profile']['password_token'] = '';
					}

				if ($this->Profile->save($this->request->data['Profile'])) {
					$status = 'success';
					$Email = new CakeEmail();
					$Email->template('password_changed')
						->viewVars(['profile' => $data['Profile']])
						->subject('Your password has changed')
						->to($data['Profile']['email'])
						->send();
				}
			}
		} elseif(!empty($data)) {
			if(!empty($data['Profile']['password_timeout']) && $data['Profile']['password_timeout'] >= time()) {
				$status = 'proceed';
			}
		}
		$this->set('username', !empty($data['Profile']['username']) ? $data['Profile']['username'] : '');
		$this->set('status', $status);
	}

	public function forgot()
	{
		$this->layout = 'blank';
		Globals::$title = 'Can\'t Sign in - Pinoys on Web';
		$status = 'ok';
		if ($this->request->is('post')) {
			if(!empty($this->request->data['Profile']['username']) && $data = $this->Profile->findByUsername($this->request->data['Profile']['username'])) {
				$data['Profile']['password_token'] = uniqid();
				$data['Profile']['password_timeout'] = strtotime( "NOW + 1 HOUR");
				unset($data['Profile']['password']);
				if ($this->Profile->save($data)) {
					$Email = new CakeEmail();
					$Email->template('reset')
						->viewVars(['profile' => $data['Profile']])
						->subject('Complete your password reset request')
						->to($data['Profile']['email'])
						->send();
				}

				$status = 'success';
			} else $status = 'failed';
		}
		$this->set('status', $status);
	}

	public function signin()
	{
		$this->layout = 'blank';
		Globals::$title = 'Sign in - Pinoys on Web';
		if ($this->request->is('post')) {
			if (@$this->Auth->login()) {
				
				$tmp = $this->Profile->read(['id','login_ip'], $this->Auth->user('id'));
				$tmp['Profile']['login_ip'] = env('REMOTE_ADDR');
				$tmp['Profile']['login_date'] = date('Y-m-d H:i:s');
				$this->Profile->save($tmp);

				// if(!$this->Auth->user('signup_finished'))
				// 	return $this->redirect('/signup-next/');
				// else
					return $this->redirect($this->Auth->redirectUrl());
			}
			$this->Session->setFlash(__('Invalid username or password, try again'));
		}
	}

	public function signout() {
		return $this->redirect($this->Auth->logout());
	}

	public function upgradeOptions($current) {
		$upgradeOptions = $this->access;
		unset($upgradeOptions['free']);
		if($current != 'free')
			foreach($upgradeOptions as $i=>$row) {
				unset($upgradeOptions[$i]);
				if($i == $current)
					break;
			}
		return $upgradeOptions;
	}

}