<?php
/**
 * Application model for CakePHP.
 *
 * This file is application-wide model file. You can put all
 * application-wide model-related methods here.
 *
 * CakePHP(tm) : Rapid Development Framework (https://cakephp.org)
 * Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 *
 * Licensed under The MIT License
 * For full copyright and license information, please see the LICENSE.txt
 * Redistributions of files must retain the above copyright notice.
 *
 * @copyright     Copyright (c) Cake Software Foundation, Inc. (https://cakefoundation.org)
 * @link          https://cakephp.org CakePHP(tm) Project
 * @package       app.Model
 * @since         CakePHP(tm) v 0.2.9
 * @license       https://opensource.org/licenses/mit-license.php MIT License
 */

App::uses('Model', 'Model');

/**
 * Application model for Cake.
 *
 * Add your application-wide methods in the class below, your models
 * will inherit them.
 *
 * @package       app.Model
 */
class AppModel extends Model {

	public function alphaNumericDash($check) {
		$value = array_values($check);
		$value = $value[0];
		return preg_match('|^[0-9a-zA-Z-]*$|', $value);
	}

	public function password_confirm(){ 
		if ($this->data[$this->alias]['password_new'] !== $this->data[$this->alias]['password_confirmation']){
			return false;       
		}
		return true;
	}

	public function isAuth($id = null, $profile_id) {
		if(!$id) return true;

		return !empty($this->find('first', [
			'conditions' => [
				'id' => $id,
				'profile_id' => $profile_id
			]
		]));
	}

	public function toggle($id, $field, $profile_id) {
		if($data = $this->find('first', [
				'conditions' =>  ['id' => $id,'profile_id' => $profile_id],
				'fields' => ['id', $field]
			])) {
			$data[$this->alias][$field] = !$data[$this->alias][$field];
			$this->save($data);
		}
	}
	public function move($direction, $id, $profile_id) {
		
		if($data = $this->find('all', [
			'conditions' =>  ['profile_id' => $profile_id, ],
			'fields' => ['id', 'order'],
			'order' => ['order' => $direction=='up'?'desc':'asc']])) {

			foreach($data as $i=>$row) {
				if($row[$this->alias]['id'] == $id && !empty($data[$i+1][$this->alias]['order'])) {
					$tmpOrder = $data[$i+1][$this->alias]['order'];
					$data[$i+1][$this->alias]['order'] = $row[$this->alias]['order'];
					$data[$i][$this->alias]['order'] = $tmpOrder;
					$this->saveAll($data);
					return true;
				}
			}
		}
		return true;
	}
	
	public function toSef ($string) {
		return preg_replace('/[ -]+/', '-', trim(preg_replace('/[^a-z0-9 -]/', '', strtolower(iconv('UTF-8', 'ASCII//TRANSLIT', html_entity_decode($string))))));
	}
}
