<?php
App::uses('AppModel', 'Model');
App::uses('BlowfishPasswordHasher', 'Controller/Component/Auth');
class Profile extends AppModel {

	public $useTable = 'profiles';
	public $displayField = 'username';
	public $token = '';
	public $actsAs = array('Stamps');
	public $validate = array(
		'username' => [
			'notBlank',
			'minLength' => [
				'rule' => ['minLength', '6'],
				'message' => 'Minimum of 6 characters long'
			],
			'alphaNumericDash' => [
				'rule' => 'alphaNumericDash',
				'message' => 'Usernames must only contain letters, numbers and dashes'
			],
			'isUnique' => [
				'rule' => 'isUnique',
				'message' => 'This username has already been taken'
			]
		],
		'name' => 'notBlank',
		'email' => [
			'notBlank',
			'isUnique' => [
				'rule' => 'isUnique',
				'message' => 'This email has already been used'
			]
		],
		'business_name' => 'notBlank',
		'password' => 'notBlank',
		'password_new' => [
			'notBlank',
			'password_confirm'=>[
				'rule'=> ['password_confirm'],
				'message'=>'Password Confirmation must match Password',                         
			],
			'minLength' => [
				'rule' => ['minLength', '6'],
				'message' => 'Minimum of 6 characters long'
			]
		],
		'password_confirmation' => 'notBlank',
	);

	public $accessLimits = [
		'basic' =>  ['name'=>'Basic',    'path'=>'domain', 'pages'=> 2, 'listing'=> 5, 'visitors'=> 200, 'noads'=> false, 'fbchat' => true, 'cpm' => 0],
		'plus' =>  ['name'=>'Plus',    'path'=>'domain',   'pages'=> 5, 'listing'=>20, 'visitors'=>1000, 'noads'=> true,  'fbchat' => true , 'cpm' => 400],
		'pro' =>   ['name'=>'Pro',     'path'=>'domain',   'pages'=>10, 'listing'=>40, 'visitors'=>2000, 'noads'=> true,  'fbchat' => true , 'cpm' => 800],
	];

	public function afterFind ($data, $primary = false) {
		if($this->findQueryType == 'count') return $data;
		if(!empty($this->token) && $this->token == md5(date('y-m-d').date('d-m-y')))
			return $data;
		foreach($data as $i=>$row) {
			unset($data[$i][$this->alias]['password']);
		}
		return $data;
	}
	
	public function beforeSave($options = array()) {
		parent::beforeSave();
		if (!empty($this->data[$this->alias]['password'])) {
			$passwordHasher = new BlowfishPasswordHasher();
			$this->data[$this->alias]['password'] = $passwordHasher->hash(
				$this->data[$this->alias]['password']
			);
		}
		return true;
	}
}