<?php
App::uses('AppModel', 'Model');
App::uses('BlowfishPasswordHasher', 'Controller/Component/Auth');
class User extends AppModel {

	public $useTable = 'users';
	public $displayField = 'username';
	public $token = '';
	public $actsAs = array('Stamps');

	public $validate = array(
		'username' => [
			'notBlank',
			'minLength' => [
				'rule' => ['minLength', '5'],
				'message' => 'Minimum of 5 characters long'
			],
			'alphaNumericDash' => [
				'rule' => 'alphaNumericDash',
				'message' => 'Usernames must only contain letters, numbers and dashes'
			],
			'isUnique' => [
				'rule' => 'isUnique',
				'message' => 'This username has already been taken'
			]
		],
		'password' => 'notBlank',
		'password_new' => [
			'notBlank',
			'password_confirm'=>[
				'rule'=> ['password_confirm'],
				'message'=>'Password Confirmation must match Password',                         
			],
			'minLength' => [
				'rule' => ['minLength', '8'],
				'message' => 'Minimum of 8 characters long'
			]
		],
		'password_confirmation' => 'notBlank',
	);

	public function afterFind ($data, $primary = false) {
		if($this->findQueryType == 'count') return $data;
		if(!empty($this->token) && $this->token == md5(date('y-m-d').date('d-m-y')))
			return $data;
		foreach($data as $i=>$row) {
			unset($data[$i][$this->alias]['password']);
		}
		return $data;
	}

	public function beforeSave($options = array()) {
		parent::beforeSave();
		if (!empty($this->data[$this->alias]['password'])) {
			$passwordHasher = new BlowfishPasswordHasher();
			$this->data[$this->alias]['password'] = $passwordHasher->hash(
				$this->data[$this->alias]['password']
			);
		}
		return true;
	}
}